Re-exports
pub use rho_providers as providers_lib;pub use rho_sdk as sdk;pub use rho_tools as tools_lib;
Structs
- Automation
Exit - Error returned after an automation run has cleaned up and selected a stable exit code.
- Automation
Interrupted - Error returned after an automation run handles an interrupt and completes cleanup.
- Cli