Crate rho_coding_agent

Crate rho_coding_agent 

Re-exports

pub use rho_sdk as sdk;

Macros

impl_sdk_model_provider
Implements rho_sdk::provider::ModelProvider for an application transport that already exposes inherent model_identity, complete_turn, and stream_turn methods.

Structs

AutomationInterrupted
Error returned after an automation run handles an interrupt and completes cleanup.
Cli

Functions

run